.. highlight:: shell

==========
Instalação
==========

Atualmente, a PyCEPCorreios possui suporte para Python 3.5+.

Versão estável
--------------

Para instalar PyCEPCorreios, execute este comando no seu terminal:

.. code-block:: console

    $ pip install pycep_correios

Este é o método recomendado para instalar a PyCEPCorreios. Desse modo sempre será instalado a versão mais recente.

A partir do código fonte
------------------------

O código fonte do PyCEPCorreios pode ser baixado `aqui`_.

Você pode realizar o *clone* do repositório público:

.. code-block:: console

    $ git clone https://github.com/mstuttgart/pycep-correios.git

Ou baixar o `tarball`_:

.. code-block:: console

    $ curl -OL https://github.com/mstuttgart/pycep-correios/tarball/master

Uma vez que você tenha uma cópia do código fonte, você pode instalá-lo com:

.. code-block:: console

    $ python setup.py install


.. _aqui: https://github.com/mstuttgart/pycep-correios
.. _tarball: https://github.com/mstuttgart/pycep-correios/tarball/master
